==> reformcloud2-default-application-commands-2.2.2-sources.jar: systems/reformcloud/reformcloud2/commands/plugin/bungeecord/commands/CommandReformCloud.java <==
/*
 * MIT License
 *
 * Copyright (c) ReformCloud-Team
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package systems.reformcloud.reformcloud2.commands.plugin.bungeecord.commands;

import net.md_5.bungee.api.CommandSender;
import net.md_5.bungee.api.chat.TextComponent;
import net.md_5.bungee.api.plugin.Command;
import org.jetbrains.annotations.NotNull;
import systems.reformcloud.reformcloud2.commands.plugin.internal.InternalReformCloudCommand;
import systems.reformcloud.reformcloud2.executor.api.bungee.BungeeExecutor;

import java.util.List;

public class CommandReformCloud extends Command {

    public CommandReformCloud(@NotNull String name, @NotNull List<String> aliases) {
        super(name, "reformcloud.command.reformcloud", aliases.toArray(new String[0]));
    }

    @Override
    public void execute(CommandSender commandSender, String[] strings) {
        String prefix = BungeeExecutor.getInstance().getMessages().getPrefix() + " ";
        InternalReformCloudCommand.execute(
                message -> commandSender.sendMessage(TextComponent.fromLegacyText(message)),
                strings,
                prefix,
                this.getCommandSuccessMessage(),
                super.getName()
        );
    }

    @NotNull
    private String getCommandSuccessMessage() {
        String message = BungeeExecutor.getInstance().getMessages().getCommandExecuteSuccess();
        return BungeeExecutor.getInstance().getMessages().format(message);
    }
}

==> reformcloud2-default-application-commands-2.10.0-sources.jar: systems/reformcloud/reformcloud2/commands/plugin/bungeecord/commands/CommandReformCloud.java <==
/*
 * MIT License
 *
 * Copyright (c) ReformCloud-Team
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package systems.reformcloud.reformcloud2.commands.plugin.bungeecord.commands;

import net.md_5.bungee.api.CommandSender;
import net.md_5.bungee.api.chat.TextComponent;
import net.md_5.bungee.api.plugin.Command;
import org.jetbrains.annotations.NotNull;
import systems.refomcloud.reformcloud2.embedded.Embedded;
import systems.reformcloud.reformcloud2.commands.plugin.internal.InternalReformCloudCommand;

import java.util.List;

public class CommandReformCloud extends Command {

    public CommandReformCloud(@NotNull String name, @NotNull List<String> aliases) {
        super(name, "reformcloud.command.reformcloud", aliases.toArray(new String[0]));
    }

    @Override
    public void execute(CommandSender commandSender, String[] strings) {
        String prefix = Embedded.getInstance().getIngameMessages().getPrefix();
        InternalReformCloudCommand.execute(
                message -> commandSender.sendMessage(TextComponent.fromLegacyText(message)),
                strings,
                prefix.endsWith(" ") ? prefix : prefix + " ",
                this.getCommandSuccessMessage(),
                super.getName()
        );
    }

    @NotNull
    private String getCommandSuccessMessage() {
        String message = Embedded.getInstance().getIngameMessages().getCommandExecuteSuccess();
        return Embedded.getInstance().getIngameMessages().format(message);
    }
}
